package com.ruoyi.frequency.userwithdrawalway.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.controller.resp.UserWithdrawalWayResp;
import com.ruoyi.frequency.userwithdrawalway.entity.UserWithdrawalWay;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 用户提现方式Mapper接口
 * 
 * @author liwenlong
 * @date 2023-07-20
 */
public interface UserWithdrawalWayMapper  extends BaseMapper<UserWithdrawalWay>
{
    /**
     * 查询用户提现方式
     * 
     * @param id 用户提现方式主键
     * @return 用户提现方式
     */
    UserWithdrawalWay selectUserWithdrawalWayById(Long id);

    /**
     * 查询用户提现方式列表
     * 
     * @param userWithdrawalWay 用户提现方式
     * @return 用户提现方式集合
     */
    List<UserWithdrawalWay> selectUserWithdrawalWayList(UserWithdrawalWay userWithdrawalWay);

    /**
     * 新增用户提现方式
     * 
     * @param userWithdrawalWay 用户提现方式
     * @return 结果
     */
    int insertUserWithdrawalWay(UserWithdrawalWay userWithdrawalWay);

    /**
     * 修改用户提现方式
     * 
     * @param userWithdrawalWay 用户提现方式
     * @return 结果
     */
    int updateUserWithdrawalWay(UserWithdrawalWay userWithdrawalWay);

    /**
     * 删除用户提现方式
     * 
     * @param id 用户提现方式主键
     * @return 结果
     */
    int deleteUserWithdrawalWayById(Long id);

    /**
     * 批量删除用户提现方式
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteUserWithdrawalWayByIds(Long[] ids);

    List<UserWithdrawalWayResp> selList(@Param("userId") Long userId, @Param("userType") Integer userType);

    UserWithdrawalWayResp getDetail(@Param("id") Long id);

    UserWithdrawalWayResp defaultWay(@Param("userId") Long userId, @Param("userType") Integer userType);
}
